<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.1">



  <!--xsl:template match="*|@*">
       <xsl:message>
         Global match for: <xsl:value-of select="name()"/>
     </xsl:message>
     <xsl:copy>
       <xsl:apply-templates select="node()|@*"/>
     </xsl:copy>
   </xsl:template-->



   <xsl:template match="ul|li">	<!-- copy some HTML from standards -->
     <xsl:copy>
       <xsl:apply-templates select="node()|@*"/>
     </xsl:copy>
   </xsl:template>
   <xsl:template match="loc">	<!-- transform XLinks and my pseudo-XLinks to Anchors -->
     <a href="{@href}" class="{@class}">
       <xsl:value-of select="."/>
     </a>
   </xsl:template>



   <xsl:template match="standard[child::p]">
     <span class="standard">
       <xsl:apply-templates select="p" mode="processStandard"/>
     </span>
   </xsl:template>
   <xsl:template match="standard">
     <span class="standard">
       <xsl:apply-templates select="node()|@*"/>
     </span>
   </xsl:template>
   <xsl:template match="p" mode="processStandard">
     <xsl:apply-templates select="node()|@*"/>
     <br/>
   </xsl:template>



   <xsl:template match="code">
     <xsl:variable name="link">
       <xsl:choose>
         <xsl:when test=".='XML Namespaces'">
           <xsl:text>namespaces</xsl:text>
         </xsl:when>
         <xsl:when test="(.='namespace URI') or (.='namespace prefix') or (.='local name')">
           <xsl:value-of select="substring-before(.,' ')"/>
         </xsl:when>
         <xsl:otherwise>
           <xsl:value-of select="."/>
         </xsl:otherwise>
       </xsl:choose>
     </xsl:variable>
     <xsl:choose>
       <xsl:when test="@level">
         <a href="_glossary.html#{$link}" class="code"><xsl:value-of select="."/></a>
       </xsl:when>
       <xsl:otherwise>
         <a href="../_glossary.html#{$link}" class="code"><xsl:value-of select="."/></a>
       </xsl:otherwise>
     </xsl:choose>
   </xsl:template>



   <xsl:template match="bibref[contains(text(),'RFC')]">
     <a href="http://zvon.org/tmRFC/{text()}/Output/index.html"><xsl:value-of select="text()"/></a>
   </xsl:template>



   <xsl:template name="interfaceDetector">
     <xsl:choose>
       <xsl:when test="@type='DOMString' or @type='Boolean' or @type='DOMException' or @type='unsigned long' or @type='unsigned short' or @type='long' or @type='DOMTimeStamp'">
         <xsl:choose>
           <xsl:when test="@type='unsigned long' or @type='unsigned short'">
             <a href="../_glossary.html#unsigned" class="code">
               <xsl:value-of select="substring-before(@type,' ')"/>
             </a>
           </xsl:when>
           <xsl:otherwise>
             <a href="../_glossary.html#{@type}" class="code">
               <xsl:value-of select="@type"/>
             </a>
           </xsl:otherwise>
         </xsl:choose>
       </xsl:when>
       <xsl:otherwise> <!-- so it must be interface -->
         <xsl:variable name="prePath">
           <xsl:choose>
             <xsl:when test="@module"><xsl:text>../</xsl:text><xsl:value-of select="@module"/><xsl:text>/</xsl:text></xsl:when>
             <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
           </xsl:choose>
         </xsl:variable>
         <xsl:variable name="path">
           <xsl:value-of select="$prePath"/><xsl:text>interface_</xsl:text><xsl:value-of select="@type"/><xsl:text>.html</xsl:text>
         </xsl:variable>
         <a href="{$path}" class="interface"><xsl:value-of select="@type"/></a>
       </xsl:otherwise>
     </xsl:choose>
   </xsl:template>



   <xsl:template match="infc[@module='Exceptions']">
     <a href="_exceptions.html#{.}" class="interface"><xsl:value-of select="child::node()"/></a>
   </xsl:template>
   <xsl:template match="infc">
     <xsl:variable name="prePath">
       <xsl:choose>
         <xsl:when test="@module and @level"><xsl:value-of select="@module"/><xsl:text>/</xsl:text></xsl:when>   <!-- for _exceptions.html -->
         <xsl:when test="@module"><xsl:text>../</xsl:text><xsl:value-of select="@module"/><xsl:text>/</xsl:text></xsl:when>
         <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
       </xsl:choose>
     </xsl:variable>
     <xsl:variable name="path">
       <xsl:value-of select="$prePath"/><xsl:text>interface_</xsl:text><xsl:value-of select="child::node()"/><xsl:text>.html</xsl:text>
     </xsl:variable>
     <a href="{$path}" class="interface"><xsl:value-of select="child::node()"/></a>
   </xsl:template>



   <xsl:template match="attr">
     <xsl:variable name="prePath">
       <xsl:choose>
         <xsl:when test="@module"><xsl:text>../</xsl:text><xsl:value-of select="@module"/><xsl:text>/</xsl:text></xsl:when>
         <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
       </xsl:choose>
     </xsl:variable>
     <xsl:variable name="path">
       <xsl:value-of select="$prePath"/><xsl:text>attribute_</xsl:text><xsl:value-of select="."/><xsl:text>_</xsl:text><xsl:value-of select="@for"/><xsl:text>.html</xsl:text>
     </xsl:variable>
     <a href="{$path}" class="attributeFg"><xsl:value-of select="child::node()"/></a>
   </xsl:template>

   <xsl:template match="mtd">
     <xsl:variable name="prePath">
       <xsl:choose>
         <xsl:when test="@module"><xsl:text>../</xsl:text><xsl:value-of select="@module"/><xsl:text>/</xsl:text></xsl:when>
         <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
       </xsl:choose>
     </xsl:variable>
     <xsl:variable name="path">
       <xsl:value-of select="$prePath"/><xsl:text>method_</xsl:text><xsl:value-of select="."/><xsl:text>_</xsl:text><xsl:value-of select="@for"/><xsl:text>.html</xsl:text>
     </xsl:variable>
     <a href="{$path}" class="methodFg"><xsl:value-of select="child::node()"/></a>
   </xsl:template>

   <xsl:template match="prm">
     <span class="parameter"><xsl:value-of select="child::node()"/></span>
   </xsl:template>



   <xsl:template match="exception">
     <dl>
       <dt>
         <a href="../_exceptions.html#{@type}" class="code"><xsl:value-of select="@type"/></a>&#160;<a href="../_exceptions.html#{@name}" class="code"><xsl:value-of select="@name"/></a>
       </dt>
       <dd>
         <xsl:apply-templates select="desc|descr"/>
       </dd>
     </dl>
   </xsl:template>



   <xsl:template match="interface" mode="members">
     <xsl:choose>
       <xsl:when test="name(..)='parent' and ../following-sibling::children">
         <xsl:apply-templates select="../following-sibling::children//interface" mode="list">
           <xsl:sort select="@name"/>
         </xsl:apply-templates>
       </xsl:when>
       <xsl:otherwise>
         <xsl:text>none</xsl:text>
       </xsl:otherwise>
     </xsl:choose>
   </xsl:template>
   <xsl:template match="interface" mode="list">
     <a class="interface" href="interface_{@name}.html">
       <xsl:value-of select="@name"/>
     </a>
     <xsl:if test="not(position()=last())">, </xsl:if>
   </xsl:template>



   <xsl:template match="group">
     <xsl:choose>
       <xsl:when test="ancestor::exceptions">
         <div class="bold2">Types of error:</div>
       </xsl:when>
       <xsl:when test="ancestor::interface[@name='Event']">
         <div class="bold2">Event Phase Types:</div>
       </xsl:when>
       <xsl:when test="ancestor::interface[@name='MutationEvent']">
         <div class="bold2">Mutation Event Types:</div>
       </xsl:when>
       <xsl:when test="ancestor::method[@name='compareBoundaryPoints']">
         <div class="bold2">Boundary Points Types:</div>
       </xsl:when>
       <xsl:when test="ancestor::method[@name='acceptNode']">
         <div class="bold2">Possible Constants to Return:</div>
       </xsl:when>
       <xsl:when test="ancestor::attribute[@name='whatToShow']">
         <div class="bold2">Available values for the <i>whatToShow</i> attribute:</div>
       </xsl:when>
       <xsl:otherwise/>
     </xsl:choose>
     <div class="dataBody">
       <xsl:apply-templates select="descr"/>
     </div>
     <dl>
       <xsl:apply-templates select="constant"/>
     </dl>
     <xsl:if test="note">
       <br/>
       <div>
         <xsl:text>(</xsl:text>
         <xsl:apply-templates select="note">
           <xsl:with-param name="module">Exceptions</xsl:with-param>
         </xsl:apply-templates>
         <xsl:text>)</xsl:text>
       </div>
     </xsl:if>
   </xsl:template>
   <xsl:template match="constant">
     <a name="{@name}"/>
     <dt>
       <b><xsl:if test="string-length(@value) = 1">&#160;&#160;</xsl:if><xsl:value-of select="@value"/></b>
       <xsl:text> = </xsl:text>
       <b><xsl:value-of select="@name"/></b>
       <xsl:choose>
         <xsl:when test="ancestor::exceptions">
           <xsl:text> (of type </xsl:text><a href="_glossary.html#unsigned" class="code"><xsl:value-of select="@type"/></a><xsl:text>)</xsl:text>
         </xsl:when>
         <xsl:when test="contains(@type,' ')">
           <xsl:text> (of type </xsl:text><a href="../_glossary.html#{substring-before(@type,' ')}" class="code"><xsl:value-of select="@type"/></a><xsl:text>)</xsl:text>
         </xsl:when>
         <xsl:otherwise>
           <xsl:text> (of type </xsl:text><a href="../_glossary.html#{@type}" class="code"><xsl:value-of select="@type"/></a><xsl:text>)</xsl:text>
`         </xsl:otherwise>
       </xsl:choose>
     </dt>
     <dd>
       <xsl:apply-templates select="descr"/>
     </dd>
   </xsl:template>



   <xsl:template name="structure">
     <xsl:param name="module"/>
     <xsl:param name="interface"/>
     <xsl:param name="property">null</xsl:param>
     <!--xsl:message>
       STRUCTURE called for <xsl:value-of select="$interface"/> &amp; <xsl:value-of select="$property"/>
     </xsl:message-->
     <span class="mediumText">
       <a class="naviBlack" href="../index.html" target="_top">DOM2 reference</a>
       <xsl:text> &gt; </xsl:text>
       <b><xsl:value-of select="$module"/><xsl:text>: </xsl:text></b>
       <xsl:choose>
         <xsl:when test="($module='Core') and not($property='null')">
           <a class="naviBlack" href="../Core/interface_{$interface}.html"><xsl:value-of select="$interface"/></a>
         </xsl:when>
         <xsl:when test="($module='HTML') and not($property='null')">
           <a class="naviBlack" href="../HTML/interface_{$interface}.html"><xsl:value-of select="$interface"/></a>
         </xsl:when>
         <xsl:otherwise>
           <b><xsl:value-of select="$interface"/></b>
         </xsl:otherwise>
       </xsl:choose>
       <xsl:if test="not($property='null')">
         <xsl:text> &gt; </xsl:text>
         <b><xsl:value-of select="$property"/></b>
       </xsl:if>
     </span>
   </xsl:template>



</xsl:stylesheet>
